# GIS-Lab

[![PyPI Version](https://img.shields.io/badge/Version-0.0.1-3775A9?style=plastic&logo=PyPi)](https://pypi.org/project/pylearn/)
[![Code Coverage](https://img.shields.io/badge/CodeCoverage-99p-F01F7A?style=plastic&logo=CodeCov)](https://github.com/social-learning/pylearn)
[![Github](https://img.shields.io/badge/GitHub-PyLearn-181717?style=plastic&logo=GitHub)](https://github.com/social-learning/pylearn)
[![LinkedIn](https://img.shields.io/badge/GitHub-CodeForAll-0077B5?style=plastic&logo=LinkedIn)](https://www.linkedin.com/company/codeforall/)
[![TensorFlow](https://img.shields.io/badge/TensorFlow-2.3.1-FF6F00?style=plastic&logo=TensorFlow)](https://https://www.tensorflow.org/)
[![TensorFlow](https://img.shields.io/badge/OpenAIGym-0.12.5-0081A5?style=plastic&logo=OpenAI-Gym)](https://gym.openai.com/)
[![SciKitLearn](https://img.shields.io/badge/PyTorch-1.6.0-EE4C2C?style=plastic&logo=PyTorch)](https://pytorch.org/)
